@@ -1,12 +1,8 @@
 "procrustes" <-
-function (X, Y, scale = TRUE, symmetric = FALSE) 
+    function (X, Y, scale = TRUE, symmetric = FALSE,  scores = "sites", ...) 
 {
-    if (is.list(X)) 
-        X <- scores(X, display = "sites")
-    if (is.list(Y)) 
-        Y <- scores(Y, display = "sites")
-    X <- as.matrix(X)
-    Y <- as.matrix(Y)
+    X <- scores(X, display = scores, ...)
+    Y <- scores(Y, display = scores, ...)
     if (ncol(X) < ncol(Y)) {
         warning("X has fewer axes than Y: X adjusted to comform Y\n")
         addcols <- ncol(Y) - ncol(X)
@@ -15,16 +11,16 @@ function (X, Y, scale = TRUE, symmetric = FALSE)
     ctrace <- function(MAT) sum(diag(crossprod(MAT)))
     c <- 1
     if (symmetric) {
-       X <- scale(X, scale=FALSE)
-       Y <- scale(Y, scale=FALSE)
-       X <- X/sqrt(ctrace(X))
-       Y <- Y/sqrt(ctrace(Y))
+        X <- scale(X, scale = FALSE)
+        Y <- scale(Y, scale = FALSE)
+        X <- X/sqrt(ctrace(X))
+        Y <- Y/sqrt(ctrace(Y))
     }
     xmean <- apply(X, 2, mean)
     ymean <- apply(Y, 2, mean)
     if (!symmetric) {
-      X <- scale(X, scale = FALSE)
-      Y <- scale(Y, scale = FALSE)
+        X <- scale(X, scale = FALSE)
+        Y <- scale(Y, scale = FALSE)
     }
     XY <- crossprod(X, Y)
     sol <- svd(XY)
@@ -36,8 +32,7 @@ function (X, Y, scale = TRUE, symmetric = FALSE)
     b <- xmean - t(A %*% ymean)
     R2 <- ctrace(X) + c * c * ctrace(Y) - 2 * c * sum(sol$d)
     reslt <- list(Yrot = Yrot, X = X, ss = R2, rotation = A, 
-        translation = b, scale = c, symmetric = symmetric, 
-        call = match.call())
+                  translation = b, scale = c, symmetric = symmetric, call = match.call())
     reslt$svd <- sol
     class(reslt) <- "procrustes"
     return(reslt)
